@@ -184,11 +184,11 @@ class Git:
     The Git class manages communication with the Git binary
     """
 
-    def __init__(self):
+    def __init__(self, worktree=None):
         self.paths = Paths()
 
         self._valid = {}  #: Store the result of is_git_dir() for performance
-        self.set_worktree(core.getcwd())
+        self.set_worktree(worktree or core.getcwd())
 
     def is_git_repository(self, path):
         return is_git_repository(path)
@@ -246,6 +246,7 @@ class Git:
     @staticmethod
     def execute(
         command,
+        _add_env=None,
         _cwd=None,
         _decode=True,
         _encoding=None,
@@ -291,6 +292,7 @@ class Git:
         try:
             status, out, err = core.run_command(
                 command,
+                add_env=_add_env,
                 cwd=_cwd,
                 encoding=_encoding,
                 stdin=_stdin,
@@ -335,6 +337,7 @@ class Git:
         # otherwise they'll end up in args, which is bad.
         _kwargs = {'_cwd': self.getcwd()}
         execute_kwargs = (
+            '_add_env',
             '_cwd',
             '_decode',
             '_encoding',
@@ -356,6 +359,8 @@ class Git:
             '-c',
             'diff.suppressBlankEmpty=false',
             '-c',
+            'diff.autoRefreshIndex=false',
+            '-c',
             'log.showSignature=false',
             dashify(cmd),
         ]
