@@ -537,7 +537,7 @@ class RebaseTreeWidget(standard.DraggableTreeWidget):
         context = self.context
         oid = item.oid
         params = dag.DAG(oid, 2)
-        repo = dag.RepoReader(context, params)
+        repo = dag.RepoReader(context, params, allow_git_init=False)
         commits = []
         for commit in repo.get():
             commits.append(commit)
